@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 from leeger.util.Deci import Deci
 
@@ -53,11 +54,16 @@ class AllTimeStatSheet:
     adjustedTeamSuccess: dict[str, Deci]
     adjustedTeamLuck: dict[str, Deci]
 
+    # Optional Stats
+    leagueMedianWins: Optional[dict[str, float]] = None
+    opponentLeagueMedianWins: Optional[dict[str, float]] = None
+    totalGames: Optional[dict[str, int]] = None
+
     def preferredOrderWithTitle(self) -> list[tuple[str, dict]]:
         """
         Returns all stats in the preferred order with the title for the stat.
         """
-        return [
+        response = [
             ("Games Played", self.gamesPlayed),
             ("Wins", self.wins),
             ("Losses", self.losses),
@@ -87,3 +93,11 @@ class AllTimeStatSheet:
             ("Adjusted Team Success", self.adjustedTeamSuccess),
             ("Adjusted Team Luck", self.adjustedTeamLuck)
         ]
+
+        # add optional stats if needed
+        if self.leagueMedianWins is not None:
+            response.insert(1, ("Total Games", self.totalGames))
+            response.insert(4, ("League Median Wins", self.leagueMedianWins))
+            response.insert(5, ("Opponent League Median Wins", self.opponentLeagueMedianWins))
+            
+        return response
